use axum::{
    extract::{Path, State},
    routing::get,
    Json, Router,
};
use rand::distributions::{Alphanumeric, DistString};
use sqlx::{Pool, Postgres, QueryBuilder};

use crate::model::Chat;

pub fn router(pool: Pool<Postgres>) -> Router {
    Router::new()
        .route("/new/:amount", get(create))
        .with_state(pool)
}

async fn create(Path(amount): Path<u8>, State(pool): State<Pool<Postgres>>) -> Json<Vec<Chat>> {
    let paths: Vec<String> = (0..amount)
        .map(|_| Alphanumeric.sample_string(&mut rand::thread_rng(), 6))
        .collect();

    let r: Vec<Chat> = QueryBuilder::new("insert into chats (url_path)")
        .push_values(paths, |mut b, v| {
            b.push_bind(v);
        })
        .push("returning *")
        .build_query_as()
        .fetch_all(&pool)
        .await
        .unwrap();

    Json(r)
}
