use axum::{routing::get, Router};
use sqlx::{Pool, Postgres};

const DB_URL: &str = "postgres://localhost/chatdings";
const ADMIN_TOK: &str = "meow";

mod admin;
mod chat;
mod model;
mod stat;

#[tokio::main]
async fn main() -> anyhow::Result<()> {
    let pool = Pool::<Postgres>::connect(DB_URL).await?;

    sqlx::migrate!().run(&pool).await?;

    let app = Router::new()
        .route("/", get(|| async { "<h1>gay</h1>" }))
        .route("/:path", get(chat::get))
        .with_state(pool.clone())
        .nest("/stat", stat::router(pool.clone()))
        .nest("/admin", admin::router(pool.clone()));
    let listener = tokio::net::TcpListener::bind("0.0.0.0:8080").await.unwrap();
    axum::serve(listener, app).await?;

    Ok(())
}
